@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -18,7 +18,10 @@ from ..plugin_setup import plugin
 from ..feature_table import BIOMV210Format
 from . import (TaxonomyFormat, HeaderlessTSVTaxonomyFormat, TSVTaxonomyFormat,
                DNAFASTAFormat, PairedDNASequencesDirectoryFormat,
-               AlignedDNAFASTAFormat, DifferentialFormat)
+               AlignedDNAFASTAFormat, DifferentialFormat, ProteinFASTAFormat,
+               AlignedProteinFASTAFormat, RNAFASTAFormat,
+               AlignedRNAFASTAFormat, PairedRNASequencesDirectoryFormat,
+               BLAST6Format)
 
 
 # Taxonomy format transformers
@@ -220,32 +223,16 @@ def _27(ff: BIOMV210Format) -> TSVTaxonomyFormat:
         table = biom.Table.from_hdf5(fh)
     return _biom_to_tsv_taxonomy_format(table)
 
-
-# DNA FASTA transformers
-
-class DNAIterator(collections.abc.Iterable):
-    def __init__(self, generator):
-        self.generator = generator
-
-    def __iter__(self):
-        yield from self.generator
+# common to all FASTA transformers
 
 
-class PairedDNAIterator(DNAIterator):
-    pass
+def _read_from_fasta(path, constructor=skbio.DNA):
+    return skbio.read(path, format='fasta', constructor=constructor)
 
 
-class AlignedDNAIterator(DNAIterator):
-    pass
-
-
-def _read_dna_fasta(path):
-    return skbio.read(path, format='fasta', constructor=skbio.DNA)
-
-
-def _dnafastaformats_to_series(ff):
+def _fastaformats_to_series(ff, constructor=skbio.DNA):
     data = {}
-    for sequence in _read_dna_fasta(str(ff)):
+    for sequence in _read_from_fasta(str(ff), constructor):
         id_ = sequence.metadata['id']
         if id_ in data:
             raise ValueError("FASTA format sequence IDs must be unique. The "
@@ -255,23 +242,67 @@ def _dnafastaformats_to_series(ff):
     return pd.Series(data)
 
 
-def _dnafastaformats_to_metadata(ff):
-    df = _dnafastaformats_to_series(ff).to_frame()
+def _fastaformats_to_metadata(ff, constructor=skbio.DNA):
+    df = _fastaformats_to_series(ff, constructor).to_frame()
     df = df.astype(str)
     df.index.name, df.columns = 'Feature ID', ['Sequence']
     return qiime2.Metadata(df)
 
 
-def _series_to_fasta_format(ff, data):
+def _series_to_fasta_format(ff, data, sequence_type="DNA"):
     with ff.open() as f:
         for id_, seq in data.iteritems():
-            sequence = skbio.DNA(seq, metadata={'id': id_})
+            if sequence_type == "protein":
+                sequence = skbio.Protein(seq, metadata={'id': id_})
+            elif sequence_type == "DNA":
+                sequence = skbio.DNA(seq, metadata={'id': id_})
+            elif sequence_type == "RNA":
+                sequence = skbio.RNA(seq, metadata={'id': id_})
+            else:
+                raise NotImplementedError(
+                    "pd.Series can only be converted to DNA or "
+                    "protein FASTA format.")
             skbio.io.write(sequence, format='fasta', into=f)
 
+# DNA FASTA transformers
 
+
+class NucleicAcidIterator(collections.abc.Iterable):
+    def __init__(self, generator):
+        self.generator = generator
+
+    def __iter__(self):
+        yield from self.generator
+
+
+class DNAIterator(NucleicAcidIterator):
+    pass
+
+
+class PairedDNAIterator(NucleicAcidIterator):
+    pass
+
+
+class AlignedDNAIterator(NucleicAcidIterator):
+    pass
+
+
+class RNAIterator(NucleicAcidIterator):
+    pass
+
+
+class PairedRNAIterator(NucleicAcidIterator):
+    pass
+
+
+class AlignedRNAIterator(NucleicAcidIterator):
+    pass
+
+
+# DNA Transformers
 @plugin.register_transformer
 def _9(ff: DNAFASTAFormat) -> DNAIterator:
-    generator = _read_dna_fasta(str(ff))
+    generator = _read_from_fasta(str(ff), skbio.DNA)
     return DNAIterator(generator)
 
 
@@ -335,12 +366,12 @@ def _14(data: skbio.TabularMSA) -> AlignedDNAFASTAFormat:
 
 @plugin.register_transformer
 def _15(ff: DNAFASTAFormat) -> pd.Series:
-    return _dnafastaformats_to_series(ff)
+    return _fastaformats_to_series(ff, skbio.DNA)
 
 
 @plugin.register_transformer
 def _31(ff: DNAFASTAFormat) -> qiime2.Metadata:
-    return _dnafastaformats_to_metadata(ff)
+    return _fastaformats_to_metadata(ff, skbio.DNA)
 
 
 @plugin.register_transformer
@@ -352,7 +383,7 @@ def _16(data: pd.Series) -> DNAFASTAFormat:
 
 @plugin.register_transformer
 def _18(ff: AlignedDNAFASTAFormat) -> AlignedDNAIterator:
-    generator = _read_dna_fasta(str(ff))
+    generator = _read_from_fasta(str(ff), skbio.DNA)
     return AlignedDNAIterator(generator)
 
 
@@ -365,12 +396,12 @@ def _19(data: AlignedDNAIterator) -> AlignedDNAFASTAFormat:
 
 @plugin.register_transformer
 def _33(ff: AlignedDNAFASTAFormat) -> qiime2.Metadata:
-    return _dnafastaformats_to_metadata(ff)
+    return _fastaformats_to_metadata(ff, skbio.DNA)
 
 
 @plugin.register_transformer
 def _34(ff: AlignedDNAFASTAFormat) -> pd.Series:
-    return _dnafastaformats_to_series(ff)
+    return _fastaformats_to_series(ff, skbio.DNA)
 
 
 @plugin.register_transformer
@@ -382,10 +413,221 @@ def _35(data: pd.Series) -> AlignedDNAFASTAFormat:
 
 @plugin.register_transformer
 def _36(fmt: AlignedDNAFASTAFormat) -> DNAIterator:
-    generator = _read_dna_fasta(str(fmt))
+    generator = _read_from_fasta(str(fmt), skbio.DNA)
     return DNAIterator(generator)
 
 
+# Protein FASTA transformers
+
+class ProteinIterator(collections.abc.Iterable):
+    def __init__(self, generator):
+        self.generator = generator
+
+    def __iter__(self):
+        yield from self.generator
+
+
+class AlignedProteinIterator(ProteinIterator):
+    pass
+
+
+@plugin.register_transformer
+def _37(ff: ProteinFASTAFormat) -> ProteinIterator:
+    generator = _read_from_fasta(str(ff), skbio.Protein)
+    return ProteinIterator(generator)
+
+
+@plugin.register_transformer
+def _38(data: ProteinIterator) -> ProteinFASTAFormat:
+    ff = ProteinFASTAFormat()
+    skbio.io.write(iter(data), format='fasta', into=str(ff))
+    return ff
+
+
+@plugin.register_transformer
+def _39(ff: AlignedProteinFASTAFormat) -> skbio.TabularMSA:
+    return skbio.TabularMSA.read(str(ff), constructor=skbio.Protein,
+                                 format='fasta')
+
+
+@plugin.register_transformer
+def _40(data: skbio.TabularMSA) -> AlignedProteinFASTAFormat:
+    ff = AlignedProteinFASTAFormat()
+    data.write(str(ff), format='fasta')
+    return ff
+
+
+@plugin.register_transformer
+def _41(ff: ProteinFASTAFormat) -> pd.Series:
+    return _fastaformats_to_series(ff, skbio.Protein)
+
+
+@plugin.register_transformer
+def _42(ff: ProteinFASTAFormat) -> qiime2.Metadata:
+    return _fastaformats_to_metadata(ff, skbio.Protein)
+
+
+@plugin.register_transformer
+def _43(data: pd.Series) -> ProteinFASTAFormat:
+    ff = ProteinFASTAFormat()
+    _series_to_fasta_format(ff, data, "protein")
+    return ff
+
+
+@plugin.register_transformer
+def _44(ff: AlignedProteinFASTAFormat) -> AlignedProteinIterator:
+    generator = _read_from_fasta(str(ff), skbio.Protein)
+    return AlignedProteinIterator(generator)
+
+
+@plugin.register_transformer
+def _45(data: AlignedProteinIterator) -> AlignedProteinFASTAFormat:
+    ff = AlignedProteinFASTAFormat()
+    skbio.io.write(iter(data), format='fasta', into=str(ff))
+    return ff
+
+
+@plugin.register_transformer
+def _46(ff: AlignedProteinFASTAFormat) -> qiime2.Metadata:
+    return _fastaformats_to_metadata(ff, skbio.Protein)
+
+
+@plugin.register_transformer
+def _47(ff: AlignedProteinFASTAFormat) -> pd.Series:
+    return _fastaformats_to_series(ff, skbio.Protein)
+
+
+@plugin.register_transformer
+def _48(data: pd.Series) -> AlignedProteinFASTAFormat:
+    ff = AlignedProteinFASTAFormat()
+    _series_to_fasta_format(ff, data, "protein")
+    return ff
+
+
+@plugin.register_transformer
+def _49(fmt: AlignedProteinFASTAFormat) -> ProteinIterator:
+    generator = _read_from_fasta(str(fmt), skbio.Protein)
+    return ProteinIterator(generator)
+
+
+# RNA Transformers
+@plugin.register_transformer
+def _50(ff: RNAFASTAFormat) -> RNAIterator:
+    generator = _read_from_fasta(str(ff), constructor=skbio.RNA)
+    return RNAIterator(generator)
+
+
+@plugin.register_transformer
+def _51(data: RNAIterator) -> RNAFASTAFormat:
+    ff = RNAFASTAFormat()
+    skbio.io.write(iter(data), format='fasta', into=str(ff))
+    return ff
+
+
+@plugin.register_transformer
+def _52(ff: AlignedRNAFASTAFormat) -> skbio.TabularMSA:
+    return skbio.TabularMSA.read(str(ff), constructor=skbio.RNA,
+                                 format='fasta')
+
+
+@plugin.register_transformer
+def _53(data: skbio.TabularMSA) -> AlignedRNAFASTAFormat:
+    ff = AlignedRNAFASTAFormat()
+    data.write(str(ff), format='fasta')
+    return ff
+
+
+@plugin.register_transformer
+def _54(ff: RNAFASTAFormat) -> pd.Series:
+    return _fastaformats_to_series(ff, constructor=skbio.RNA)
+
+
+@plugin.register_transformer
+def _55(ff: RNAFASTAFormat) -> qiime2.Metadata:
+    return _fastaformats_to_metadata(ff, constructor=skbio.RNA)
+
+
+@plugin.register_transformer
+def _56(data: pd.Series) -> RNAFASTAFormat:
+    ff = RNAFASTAFormat()
+    _series_to_fasta_format(ff, data, sequence_type="RNA")
+    return ff
+
+
+@plugin.register_transformer
+def _57(ff: AlignedRNAFASTAFormat) -> AlignedRNAIterator:
+    generator = _read_from_fasta(str(ff), constructor=skbio.RNA)
+    return AlignedRNAIterator(generator)
+
+
+@plugin.register_transformer
+def _58(data: AlignedRNAIterator) -> AlignedRNAFASTAFormat:
+    ff = AlignedRNAFASTAFormat()
+    skbio.io.write(iter(data), format='fasta', into=str(ff))
+    return ff
+
+
+@plugin.register_transformer
+def _59(ff: AlignedRNAFASTAFormat) -> qiime2.Metadata:
+    return _fastaformats_to_metadata(ff, constructor=skbio.RNA)
+
+
+@plugin.register_transformer
+def _60(ff: AlignedRNAFASTAFormat) -> pd.Series:
+    return _fastaformats_to_series(ff, constructor=skbio.RNA)
+
+
+@plugin.register_transformer
+def _61(data: pd.Series) -> AlignedRNAFASTAFormat:
+    ff = AlignedRNAFASTAFormat()
+    _series_to_fasta_format(ff, data, sequence_type="RNA")
+    return ff
+
+
+@plugin.register_transformer
+def _62(fmt: AlignedRNAFASTAFormat) -> RNAIterator:
+    generator = _read_from_fasta(str(fmt), constructor=skbio.RNA)
+    return RNAIterator(generator)
+
+
+@plugin.register_transformer
+def _63(df: PairedRNASequencesDirectoryFormat) -> PairedRNAIterator:
+    left = df.left_rna_sequences.view(RNAIterator)
+    right = df.right_rna_sequences.view(RNAIterator)
+
+    def read_seqs():
+        for lseq, rseq in zip_longest(left, right):
+            if rseq is None:
+                raise ValueError('more left sequences than right sequences')
+            if lseq is None:
+                raise ValueError('more right sequences than left sequences')
+            if rseq.metadata['id'] != lseq.metadata['id']:
+                raise ValueError(lseq.metadata['id'] + ' and ' +
+                                 rseq.metadata['id'] + ' differ')
+            yield lseq, rseq
+
+    return PairedRNAIterator(read_seqs())
+
+
+@plugin.register_transformer
+def _64(data: PairedRNAIterator) -> PairedRNASequencesDirectoryFormat:
+    df = PairedRNASequencesDirectoryFormat()
+    ff_left = RNAFASTAFormat()
+    ff_right = RNAFASTAFormat()
+
+    with ff_left.open() as lfile, ff_right.open() as rfile:
+        for lseq, rseq in data:
+            if rseq.metadata['id'] != lseq.metadata['id']:
+                raise ValueError(lseq.metadata['id'] + ' and ' +
+                                 rseq.metadata['id'] + ' differ')
+            skbio.io.write(lseq, format='fasta', into=lfile)
+            skbio.io.write(rseq, format='fasta', into=rfile)
+
+    df.left_rna_sequences.write_data(ff_left, RNAFASTAFormat)
+    df.right_rna_sequences.write_data(ff_right, RNAFASTAFormat)
+    return df
+
+
 # differential types
 @plugin.register_transformer
 def _222(ff: DifferentialFormat) -> pd.DataFrame:
@@ -402,3 +644,17 @@ def _224(data: pd.DataFrame) -> DifferentialFormat:
     ff = DifferentialFormat()
     qiime2.Metadata(data).save(str(ff))
     return ff
+
+
+# blast types
+@plugin.register_transformer
+def _225(ff: BLAST6Format) -> pd.DataFrame:
+    return skbio.read(str(ff), format='blast+6', into=pd.DataFrame,
+                      default_columns=True)
+
+
+@plugin.register_transformer
+def _226(data: pd.DataFrame) -> BLAST6Format:
+    ff = BLAST6Format()
+    data.to_csv(str(ff), sep='\t', header=False, index=False)
+    return ff
