@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -16,7 +16,11 @@ from q2_types.feature_data import (
     HeaderlessTSVTaxonomyDirectoryFormat, TSVTaxonomyFormat,
     TSVTaxonomyDirectoryFormat, DNAFASTAFormat, DNASequencesDirectoryFormat,
     PairedDNASequencesDirectoryFormat, AlignedDNAFASTAFormat,
-    AlignedDNASequencesDirectoryFormat, DifferentialDirectoryFormat
+    AlignedDNASequencesDirectoryFormat, DifferentialDirectoryFormat,
+    ProteinFASTAFormat, AlignedProteinFASTAFormat, FASTAFormat,
+    AlignedProteinSequencesDirectoryFormat, ProteinSequencesDirectoryFormat,
+    RNAFASTAFormat, RNASequencesDirectoryFormat, AlignedRNAFASTAFormat,
+    AlignedRNASequencesDirectoryFormat, BLAST6DirectoryFormat
 )
 from qiime2.plugin.testing import TestPluginBase
 from qiime2.plugin import ValidationError
@@ -148,9 +152,16 @@ class TestTaxonomyFormats(TestPluginBase):
                 format.validate()
 
 
-class TestDNAFASTAFormats(TestPluginBase):
+class TestNucleicAcidFASTAFormats(TestPluginBase):
     package = 'q2_types.feature_data.tests'
 
+    # DNA Format Tests
+    def test_permissive_fasta_format(self):
+        filepath = self.get_data_path('dna-sequences-gisaid.fasta')
+        format = FASTAFormat(filepath, mode='r')
+
+        format.validate()
+
     def test_dna_fasta_format_validate_positive(self):
         filepath = self.get_data_path('dna-sequences.fasta')
         format = DNAFASTAFormat(filepath, mode='r')
@@ -276,7 +287,7 @@ class TestDNAFASTAFormats(TestPluginBase):
         format = AlignedDNAFASTAFormat(filepath, mode='r')
 
         with self.assertRaisesRegex(ValidationError,
-                                    'line 4.*length 90.*length 65'):
+                                    'line 4.*length 88.*length 64'):
             format.validate()
 
     def test_aligned_dna_sequences_directory_format(self):
@@ -288,6 +299,131 @@ class TestDNAFASTAFormats(TestPluginBase):
 
         format.validate()
 
+    # RNA Format Tests
+    def test_rna_fasta_format_validate_positive(self):
+        filepath = self.get_data_path('rna-sequences.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        format.validate()
+
+    def test_rna_fasta_format_bom_passes(self):
+        filepath = self.get_data_path('rna-with-bom-passes.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        format.validate()
+
+    def test_rna_fasta_format_empty_file(self):
+        filepath = os.path.join(self.temp_dir.name, 'empty')
+        with open(filepath, 'w') as fh:
+            fh.write('\n')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        format.validate()
+
+    def test_rna_fasta_format_invalid_characters(self):
+        filepath = self.get_data_path('not-rna-sequences.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, "Invalid character '1' "
+                                                     ".*0 on line 2"):
+            format.validate()
+
+    def test_rna_fasta_format_validate_negative(self):
+        filepath = self.get_data_path('not-rna-sequences')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, 'RNAFASTA'):
+            format.validate()
+
+    def test_rna_fasta_format_consecutive_IDs(self):
+        filepath = self.get_data_path('dna-sequences-consecutive-ids.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(
+                ValidationError, 'consecutive descriptions.*1'):
+            format.validate()
+
+    def test_rna_fasta_format_missing_initial_ID(self):
+        filepath = self.get_data_path('dna-sequences-first-line-not-id.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, 'First line'):
+            format.validate()
+
+    def test_rna_fasta_format_corrupt_characters(self):
+        filepath = self.get_data_path('dna-sequences-corrupt-characters.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, 'utf-8.*2'):
+            format.validate()
+
+    def test_rna_fasta_format_bom_fails(self):
+        filepath = self.get_data_path('dna-with-bom-fails.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, 'First line'):
+            format.validate()
+
+    def test_rna_sequences_directory_format(self):
+        filepath = self.get_data_path('rna-sequences.fasta')
+        shutil.copy(filepath,
+                    os.path.join(self.temp_dir.name, 'rna-sequences.fasta'))
+        format = RNASequencesDirectoryFormat(self.temp_dir.name, mode='r')
+
+        format.validate()
+
+    def test_rna_fasta_format_duplicate_ids(self):
+        filepath = self.get_data_path('rna-sequences-with-duplicate-ids.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, '6.*duplicate.*1'):
+            format.validate()
+
+    def test_rna_fasta_format_no_id(self):
+        filepath = self.get_data_path('dna-sequences-no-id.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, '1.*missing an ID'):
+            format.validate()
+
+    def test_rna_fasta_format_id_starts_with_space(self):
+        filepath = self.get_data_path(
+            'dna-sequences-id-starts-with-space.fasta')
+        format = RNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, '1 starts with a space'):
+            format.validate()
+
+    def test_aligned_rna_fasta_format_validate_positive(self):
+        filepath = self.get_data_path('aligned-rna-sequences.fasta')
+        format = AlignedRNAFASTAFormat(filepath, mode='r')
+
+        format.validate()
+
+    def test_aligned_rna_fasta_format_validate_negative(self):
+        filepath = self.get_data_path('not-rna-sequences')
+        format = AlignedRNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError, 'AlignedRNAFASTA'):
+            format.validate()
+
+    def test_aligned_rna_fasta_format_unaligned(self):
+        filepath = self.get_data_path('rna-sequences.fasta')
+        format = AlignedRNAFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(ValidationError,
+                                    'line 4.*length 88.*length 64'):
+            format.validate()
+
+    def test_aligned_rna_sequences_directory_format(self):
+        filepath = self.get_data_path('aligned-rna-sequences.fasta')
+        temp_dir = self.temp_dir.name
+        shutil.copy(filepath,
+                    os.path.join(temp_dir, 'aligned-rna-sequences.fasta'))
+        format = AlignedRNASequencesDirectoryFormat(temp_dir, mode='r')
+
+        format.validate()
+
 
 class TestDifferentialFormat(TestPluginBase):
     package = 'q2_types.feature_data.tests'
@@ -342,5 +478,90 @@ class TestDifferentialFormat(TestPluginBase):
             format.validate()
 
 
+class TestProteinFASTAFormats(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_protein_fasta_format_validate_positive(self):
+        filepath = self.get_data_path('protein-sequences.fasta')
+        format = ProteinFASTAFormat(filepath, mode='r')
+
+        format.validate()
+        format.validate('min')
+
+    def test_protein_fasta_format_invalid_characters(self):
+        filepath = self.get_data_path('not-dna-sequences.fasta')
+        format = ProteinFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(
+                ValidationError, "Invalid character '1' .*0 on line 2"):
+            format.validate()
+
+    def test_protein_fasta_format_empty_file(self):
+        filepath = os.path.join(self.temp_dir.name, 'empty')
+        with open(filepath, 'w') as fh:
+            fh.write('\n')
+        format = ProteinFASTAFormat(filepath, mode='r')
+
+        format.validate()
+
+    def test_protein_sequences_directory_format(self):
+        filepath = self.get_data_path('protein-sequences.fasta')
+        shutil.copy(filepath,
+                    os.path.join(
+                        self.temp_dir.name, 'protein-sequences.fasta'))
+        format = ProteinSequencesDirectoryFormat(self.temp_dir.name, mode='r')
+
+        format.validate()
+
+    def test_aligned_protein_fasta_format_validate_positive(self):
+        filepath = self.get_data_path('aligned-protein-sequences.fasta')
+        format = AlignedProteinFASTAFormat(filepath, mode='r')
+
+        format.validate()
+        format.validate('min')
+
+    def test_aligned_protein_fasta_format_unaligned(self):
+        filepath = self.get_data_path('protein-sequences.fasta')
+        format = AlignedProteinFASTAFormat(filepath, mode='r')
+
+        with self.assertRaisesRegex(
+                ValidationError, 'line 5 was length 93.* previous .* 70'):
+            format.validate()
+
+    def test_aligned_protein_sequences_directory_format(self):
+        filepath = self.get_data_path('aligned-protein-sequences.fasta')
+        temp_dir = self.temp_dir.name
+        shutil.copy(filepath,
+                    os.path.join(temp_dir, 'aligned-protein-sequences.fasta'))
+        format = AlignedProteinSequencesDirectoryFormat(temp_dir, mode='r')
+
+        format.validate()
+
+
+class TestBLAST6Format(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_blast6_format(self):
+        filepath = self.get_data_path('blast6.tsv')
+        temp_dir = self.temp_dir.name
+        shutil.copy(filepath, os.path.join(temp_dir, 'blast6.tsv'))
+        format = BLAST6DirectoryFormat(temp_dir, mode='r')
+        format.validate()
+        self.assertTrue(True)
+
+    def test_blast6_format_empty(self):
+        temp_dir = self.temp_dir.name
+        open(os.path.join(temp_dir, 'blast6.tsv'), 'w').close()
+        with self.assertRaisesRegex(ValidationError, 'BLAST6 file is empty.'):
+            BLAST6DirectoryFormat(temp_dir, mode='r').validate()
+
+    def test_blast6_format_invalid(self):
+        filepath = self.get_data_path('blast6_invalid.tsv')
+        temp_dir = self.temp_dir.name
+        shutil.copy(filepath, os.path.join(temp_dir, 'blast6.tsv'))
+        with self.assertRaisesRegex(ValidationError, 'Invalid BLAST6 format.'):
+            BLAST6DirectoryFormat(temp_dir, mode='r').validate()
+
+
 if __name__ == '__main__':
     unittest.main()
