@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -15,16 +15,19 @@ import biom
 import skbio
 import qiime2
 
-from pandas.util.testing import assert_frame_equal, assert_series_equal
+from pandas.testing import assert_frame_equal, assert_series_equal
 from q2_types.feature_table import BIOMV210Format
 from q2_types.feature_data import (
     TaxonomyFormat, HeaderlessTSVTaxonomyFormat, TSVTaxonomyFormat,
     DNAFASTAFormat, DNAIterator, PairedDNAIterator,
     PairedDNASequencesDirectoryFormat, AlignedDNAFASTAFormat,
-    DifferentialFormat, AlignedDNAIterator
+    DifferentialFormat, AlignedDNAIterator, ProteinFASTAFormat,
+    AlignedProteinFASTAFormat, RNAFASTAFormat, AlignedRNAFASTAFormat,
+    RNAIterator, AlignedRNAIterator, BLAST6Format
 )
 from q2_types.feature_data._transformer import (
-    _taxonomy_formats_to_dataframe, _dataframe_to_tsv_taxonomy_format)
+    _taxonomy_formats_to_dataframe, _dataframe_to_tsv_taxonomy_format,
+    ProteinIterator, AlignedProteinIterator)
 from qiime2.plugin.testing import TestPluginBase
 
 
@@ -744,6 +747,187 @@ class TestDNAFASTAFormatTransformers(TestPluginBase):
             self.assertEqual(observed, expected)
 
 
+class TestRNAFASTAFormatTransformers(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_rna_fasta_format_to_rna_iterator(self):
+        input, obs = self.transform_format(RNAFASTAFormat, RNAIterator,
+                                           filename='rna-sequences.fasta')
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.RNA)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+    def test_rna_iterator_to_rna_fasta_format(self):
+        transformer = self.get_transformer(RNAIterator, RNAFASTAFormat)
+        filepath = self.get_data_path('rna-sequences.fasta')
+        generator = skbio.read(filepath, format='fasta', constructor=skbio.RNA)
+        input = RNAIterator(generator)
+
+        obs = transformer(input)
+        self.assertIsInstance(obs, RNAFASTAFormat)
+        obs = skbio.read(str(obs), format='fasta', constructor=skbio.RNA)
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_aln_rna_fasta_format_to_aln_rna_iterator(self):
+        filename = 'aligned-rna-sequences.fasta'
+        input, obs = self.transform_format(AlignedRNAFASTAFormat,
+                                           AlignedRNAIterator,
+                                           filename=filename)
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.RNA)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+    def test_aln_rna_iterator_to_aln_rna_fasta_format(self):
+        transformer = self.get_transformer(AlignedRNAIterator,
+                                           AlignedRNAFASTAFormat)
+        filepath = self.get_data_path('aligned-rna-sequences.fasta')
+        generator = skbio.read(filepath, format='fasta', constructor=skbio.RNA)
+        input = AlignedRNAIterator(generator)
+
+        obs = transformer(input)
+        self.assertIsInstance(obs, AlignedRNAFASTAFormat)
+        obs = skbio.read(str(obs), format='fasta', constructor=skbio.RNA)
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_aligned_rna_fasta_format_to_skbio_tabular_msa(self):
+        filename = 'aligned-rna-sequences.fasta'
+        input, obs = self.transform_format(AlignedRNAFASTAFormat,
+                                           skbio.TabularMSA, filename=filename)
+        exp = skbio.TabularMSA.read(str(input), constructor=skbio.RNA,
+                                    format='fasta')
+
+        for act, exp in zip(obs, exp):
+            self.assertEqual(act, exp)
+
+    def test_skbio_tabular_msa_to_aligned_rna_fasta_format(self):
+        filepath = self.get_data_path('aligned-rna-sequences.fasta')
+        transformer = self.get_transformer(skbio.TabularMSA,
+                                           AlignedRNAFASTAFormat)
+        input = skbio.TabularMSA.read(filepath, constructor=skbio.RNA,
+                                      format='fasta')
+        obs = transformer(input)
+        obs = skbio.TabularMSA.read(str(obs), constructor=skbio.RNA,
+                                    format='fasta')
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_rnafasta_format_to_series(self):
+        _, obs = self.transform_format(RNAFASTAFormat, pd.Series,
+                                       'rna-sequences.fasta')
+
+        obs = obs.astype(str)
+
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'])
+        exp = pd.Series(['ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUA'
+                         'CGUACGUACGUACGUACGU', 'ACGUACGUACGUACGUACGUAC'
+                         'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACG'
+                         'UACGUACGUACGUACGUACGU'], index=index, dtype=object)
+
+        assert_series_equal(exp, obs)
+
+    def test_series_to_rnafasta_format(self):
+        transformer = self.get_transformer(pd.Series, RNAFASTAFormat)
+
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'])
+        input = pd.Series(['ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUA'
+                           'CGUACGUACGUACGUACGU', 'ACGUACGUACGUACGUACGUAC'
+                           'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACG'
+                           'UACGUACGUACGUACGUACGU'], index=index, dtype=object)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, RNAFASTAFormat)
+
+    def test_rnafasta_format_with_duplicate_ids_to_series(self):
+        with self.assertRaisesRegex(ValueError, 'unique.*RNASEQUENCE1'):
+            self.transform_format(RNAFASTAFormat, pd.Series,
+                                  'rna-sequences-with-duplicate-ids.fasta')
+
+    def test_rnafasta_format_to_metadata(self):
+        _, obs = self.transform_format(RNAFASTAFormat, qiime2.Metadata,
+                                       'rna-sequences.fasta')
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'], name='Feature ID')
+        exp_df = pd.DataFrame(['ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUA'
+                               'CGUACGUACGUACGUACGU', 'ACGUACGUACGUACGUACGUAC'
+                               'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACG'
+                               'UACGUACGUACGUACGUACGU'], index=index,
+                              columns=['Sequence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_aligned_rnafasta_format_to_metadata(self):
+        _, obs = self.transform_format(AlignedRNAFASTAFormat, qiime2.Metadata,
+                                       'aligned-rna-sequences.fasta')
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'], name='Feature ID')
+        exp_df = pd.DataFrame(['------------------------ACGUACGUACGUACGUACGUAC'
+                               'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU',
+                               'ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUAC'
+                               'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU'],
+                              index=index, columns=['Sequence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_aligned_rnafasta_format_to_series(self):
+        _, obs = self.transform_format(AlignedRNAFASTAFormat, pd.Series,
+                                       'aligned-rna-sequences.fasta')
+
+        obs = obs.astype(str)
+
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'])
+        exp = pd.Series(['------------------------ACGUACGUACGUACGUACGUAC'
+                         'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU',
+                         'ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUAC'
+                         'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU'],
+                        index=index, dtype=object)
+
+        assert_series_equal(exp, obs)
+
+    def test_series_to_aligned_rnafasta_format(self):
+        transformer = self.get_transformer(pd.Series, AlignedRNAFASTAFormat)
+
+        index = pd.Index(['RNASEQUENCE1', 'RNASEQUENCE2'])
+        input = pd.Series(['------------------------ACGUACGUACGUACGUACGUAC'
+                           'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU',
+                           'ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUAC'
+                           'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU'],
+                          index=index, dtype=object)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, AlignedRNAFASTAFormat)
+
+        obs_lines = list(open(str(obs)))
+        self.assertEqual(obs_lines[0], '>RNASEQUENCE1\n')
+        self.assertEqual(obs_lines[1],
+                         '------------------------ACGUACGUACGUACGUACGUAC'
+                         'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU\n')
+        self.assertEqual(obs_lines[2], '>RNASEQUENCE2\n')
+        self.assertEqual(obs_lines[3],
+                         'ACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGUAC'
+                         'GUACGUACGUACGUACGUACGUACGUACGUACGUACGUACGU\n')
+
+    def test_aligned_rna_fasta_format_to_rna_iterator(self):
+        input, obs = self.transform_format(
+            AlignedRNAFASTAFormat, RNAIterator,
+            filename='aligned-rna-sequences.fasta')
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.RNA)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+
 class TestDifferentialTransformer(TestPluginBase):
     package = 'q2_types.feature_data.tests'
 
@@ -781,5 +965,235 @@ class TestDifferentialTransformer(TestPluginBase):
         self.assertIsInstance(obs, DifferentialFormat)
 
 
+class TestProteinFASTAFormatTransformers(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_protein_fasta_format_to_protein_iterator(self):
+        input, obs = self.transform_format(ProteinFASTAFormat, ProteinIterator,
+                                           filename='protein-sequences.fasta')
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.Protein)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+    def test_protein_iterator_to_protein_fasta_format(self):
+        transformer = self.get_transformer(
+            ProteinIterator, ProteinFASTAFormat)
+        filepath = self.get_data_path('protein-sequences.fasta')
+        generator = skbio.read(
+            filepath, format='fasta', constructor=skbio.Protein)
+        input = ProteinIterator(generator)
+
+        obs = transformer(input)
+        self.assertIsInstance(obs, ProteinFASTAFormat)
+        obs = skbio.read(str(obs), format='fasta', constructor=skbio.Protein)
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_aln_protein_fasta_format_to_aln_protein_iterator(self):
+        filename = 'aligned-protein-sequences.fasta'
+        input, obs = self.transform_format(AlignedProteinFASTAFormat,
+                                           AlignedProteinIterator,
+                                           filename=filename)
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.Protein)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+    def test_aln_protein_iterator_to_aln_protein_fasta_format(self):
+        transformer = self.get_transformer(AlignedProteinIterator,
+                                           AlignedProteinFASTAFormat)
+        filepath = self.get_data_path('aligned-protein-sequences.fasta')
+        generator = skbio.read(
+            filepath, format='fasta', constructor=skbio.Protein)
+        input = AlignedProteinIterator(generator)
+
+        obs = transformer(input)
+        self.assertIsInstance(obs, AlignedProteinFASTAFormat)
+        obs = skbio.read(str(obs), format='fasta', constructor=skbio.Protein)
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_aligned_protein_fasta_format_to_skbio_tabular_msa(self):
+        filename = 'aligned-protein-sequences.fasta'
+        input, obs = self.transform_format(AlignedProteinFASTAFormat,
+                                           skbio.TabularMSA, filename=filename)
+        exp = skbio.TabularMSA.read(str(input), constructor=skbio.Protein,
+                                    format='fasta')
+
+        for act, exp in zip(obs, exp):
+            self.assertEqual(act, exp)
+
+    def test_skbio_tabular_msa_to_aligned_protein_fasta_format(self):
+        filepath = self.get_data_path('aligned-protein-sequences.fasta')
+        transformer = self.get_transformer(skbio.TabularMSA,
+                                           AlignedProteinFASTAFormat)
+        input = skbio.TabularMSA.read(filepath, constructor=skbio.Protein,
+                                      format='fasta')
+        obs = transformer(input)
+        obs = skbio.TabularMSA.read(str(obs), constructor=skbio.Protein,
+                                    format='fasta')
+
+        for act, exp in zip(obs, input):
+            self.assertEqual(act, exp)
+
+    def test_proteinfasta_format_to_series(self):
+        _, obs = self.transform_format(ProteinFASTAFormat, pd.Series,
+                                       'protein-sequences.fasta')
+
+        obs = obs.astype(str)
+
+        index = pd.Index(['sequence1', 'sequence2'])
+        exp = pd.Series(['MTTRDLTAAQFNETIQSSDMVLVDYWASWCGPCRAFAPTFAESSEK'
+                         'HPDVVHAKVDTEAERELAAAAQIR',
+                         'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPCKMIKPFFHSLS'
+                         'EKYSNVIFLEVDVDDCQDVASECEVKCMPTFQFFKKGQKVGEFSGAN'],
+                        index=index, dtype=object)
+
+        assert_series_equal(exp, obs)
+
+    def test_series_to_proteinfasta_format(self):
+        transformer = self.get_transformer(pd.Series, ProteinFASTAFormat)
+
+        index = pd.Index(['sequence1', 'sequence2'])
+        input = pd.Series(['MTTRDLTAAQFNETIQSSDMVLVDYWASWCGPCRAFAPTFAESSEK'
+                           'HPDVVHAKVDTEAERELAAAAQIR',
+                           'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPCKMIKPFFHSLS'
+                           'EKYSNVIFLEVDVDDCQDVASECEVKCMPTFQFFKKGQKVGEFSGAN'],
+                          index=index, dtype=object)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, ProteinFASTAFormat)
+
+    def test_proteinfasta_format_with_duplicate_ids_to_series(self):
+        with self.assertRaisesRegex(ValueError, 'unique.*sequence1'):
+            self.transform_format(
+                ProteinFASTAFormat,
+                pd.Series,
+                'protein-sequences-duplicate-ids.fasta')
+
+    def test_proteinfasta_format_to_metadata(self):
+        _, obs = self.transform_format(ProteinFASTAFormat, qiime2.Metadata,
+                                       'protein-sequences.fasta')
+        index = pd.Index(['sequence1', 'sequence2'], name='Feature ID')
+        exp_df = pd.DataFrame(['MTTRDLTAAQFNETIQSSDMVLVDYWASWCGPCRA'
+                               'FAPTFAESSEKHPDVVHAKVDTEAERELAAAAQIR',
+                               'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPC'
+                               'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                               'VKCMPTFQFFKKGQKVGEFSGAN'],
+                              index=index, columns=['Sequence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_aligned_proteinfasta_format_to_metadata(self):
+        _, obs = self.transform_format(AlignedProteinFASTAFormat,
+                                       qiime2.Metadata,
+                                       'aligned-protein-sequences.fasta')
+        index = pd.Index(['sequence1', 'sequence2'], name='Feature ID')
+        exp_df = pd.DataFrame(['------------------------VDFSATWCGPC'
+                               'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                               'VKCMPTFQFFKKGQKVGEFSGAN',
+                               'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPC'
+                               'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                               'VKCMPTFQ-------VGEFSGAN'],
+                              index=index, columns=['Sequence'], dtype=object)
+        exp = qiime2.Metadata(exp_df)
+
+        self.assertEqual(exp, obs)
+
+    def test_aligned_proteinfasta_format_to_series(self):
+        _, obs = self.transform_format(AlignedProteinFASTAFormat, pd.Series,
+                                       'aligned-protein-sequences.fasta')
+
+        obs = obs.astype(str)
+
+        index = pd.Index(['sequence1', 'sequence2'])
+        exp = pd.Series(['------------------------VDFSATWCGPC'
+                         'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                         'VKCMPTFQFFKKGQKVGEFSGAN',
+                         'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPC'
+                         'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                         'VKCMPTFQ-------VGEFSGAN'],
+                        index=index, dtype=object)
+
+        assert_series_equal(exp, obs)
+
+    def test_series_to_aligned_proteinfasta_format(self):
+        transformer = self.get_transformer(
+            pd.Series, AlignedProteinFASTAFormat)
+
+        index = pd.Index(['sequence1', 'sequence2'])
+        input = pd.Series(['------------------------VDFSATWCGPC'
+                           'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                           'VKCMPTFQFFKKGQKVGEFSGAN',
+                           'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPC'
+                           'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                           'VKCMPTFQ-------VGEFSGAN'],
+                          index=index, dtype=object)
+
+        obs = transformer(input)
+
+        self.assertIsInstance(obs, AlignedProteinFASTAFormat)
+
+        obs_lines = list(open(str(obs)))
+        self.assertEqual(obs_lines[0], '>sequence1\n')
+        self.assertEqual(obs_lines[1],
+                         '------------------------VDFSATWCGPC'
+                         'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                         'VKCMPTFQFFKKGQKVGEFSGAN\n')
+        self.assertEqual(obs_lines[2], '>sequence2\n')
+        self.assertEqual(obs_lines[3],
+                         'MVKQIESKTAFQEALDAAGDKLVVVDFSATWCGPC'
+                         'KMIKPFFHSLSEKYSNVIFLEVDVDDCQDVASECE'
+                         'VKCMPTFQ-------VGEFSGAN\n')
+
+    def test_aligned_protein_fasta_format_to_protein_iterator(self):
+        input, obs = self.transform_format(
+            AlignedProteinFASTAFormat, ProteinIterator,
+            filename='aligned-protein-sequences.fasta')
+
+        exp = skbio.read(str(input), format='fasta', constructor=skbio.Protein)
+
+        for observed, expected in zip(obs, exp):
+            self.assertEqual(observed, expected)
+
+
+class TestBLAST6Transformer(TestPluginBase):
+    package = 'q2_types.feature_data.tests'
+
+    def test_blast6_to_df(self):
+
+        _, obs = self.transform_format(BLAST6Format, pd.DataFrame,
+                                       filename='blast6.tsv')
+        self.assertEqual(obs.shape[0], 2)
+        self.assertListEqual(obs.columns.tolist(), [
+            'qseqid', 'sseqid', 'pident', 'length', 'mismatch', 'gapopen',
+            'qstart', 'qend', 'sstart', 'send', 'evalue', 'bitscore'])
+        self.assertListEqual(obs['pident'].tolist(), [100.0, 99.38])
+        self.assertListEqual(obs['mismatch'].tolist(), [0.0, 1.0])
+        self.assertListEqual(obs['bitscore'].tolist(), [330.0, 329.0])
+
+    def test_df_to_blast6(self):
+        transformer = self.get_transformer(pd.DataFrame, BLAST6Format)
+
+        columns = [
+            'qseqid', 'sseqid', 'pident', 'length', 'mismatch', 'gapopen',
+            'qstart', 'qend', 'sstart', 'send', 'evalue', 'bitscore']
+        data = [
+            ['moaC', 'gi|15800534|ref|NP_286546.1|', 100.0, 161.0, 0.0, 0.0,
+                1.0, 161.0, 1.0, 161.0, 2e-114, 330.0],
+            ['moaC', 'gi|170768970|ref|ZP_02903423.1|', 99.38, 161.0, 1.0,
+                0.0, 1.0, 161.0, 1.0, 161.0, 8e-114, 329.0]]
+        input = pd.DataFrame(data=data, columns=columns)
+        obs = transformer(input)
+        self.assertIsInstance(obs, BLAST6Format)
+
+
 if __name__ == '__main__':
     unittest.main()
