@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -12,7 +12,7 @@ import biom
 import pandas as pd
 import qiime2
 
-from pandas.util.testing import assert_frame_equal
+from pandas.testing import assert_frame_equal
 from q2_types.feature_table import BIOMV100Format, BIOMV210Format
 from qiime2.plugin.testing import TestPluginBase
 from q2_types.feature_table._transformer import (_parse_biom_table_v100,
