@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -10,9 +10,10 @@ import unittest
 
 import skbio
 import pandas as pd
+import pandas.testing as pdt
 
 import qiime2
-from q2_types.ordination import OrdinationFormat
+from q2_types.ordination import OrdinationFormat, ProcrustesStatisticsFmt
 from qiime2.plugin.testing import TestPluginBase
 
 
@@ -78,6 +79,54 @@ class TestTransformers(TestPluginBase):
         columns = ['Axis %d' % i for i in range(1, 9)]
         self.assertEqual(columns, list(obs.columns))
 
+    def test_df_to_procrustes_m2_stats_fmt(self):
+        input_df = pd.DataFrame({'true M^2 value': [1],
+                                 'p-value for true M^2 value': [0.2],
+                                 'number of Monte Carlo permutations': [300]},
+                                index=pd.Index(['results'], name='id'))
+
+        exp = ['id\ttrue M^2 value\tp-value for true M^2 value\t'
+               'number of Monte Carlo permutations\n',
+               '#q2:types\tnumeric\tnumeric\tnumeric\n',
+               'results\t1\t0.2\t300\n']
+
+        transformer = self.get_transformer(pd.DataFrame,
+                                           ProcrustesStatisticsFmt)
+        fmt = transformer(input_df)
+        with open(str(fmt), 'r') as fh:
+            obs = fh.readlines()
+
+        self.assertEqual(exp, obs)
+
+    def test_procrustes_m2_stats_fmt_to_df(self):
+        filepath = self.get_data_path('m2stats-999-permus.tsv')
+        input_fmt = ProcrustesStatisticsFmt(filepath, mode='r')
+        exp = pd.DataFrame({'true M^2 value': [0.0789623748362618],
+                            'p-value for true M^2 value': [0.001],
+                            'number of Monte Carlo permutations': [999]},
+                           index=pd.Index(['results'], name='id'))
+
+        transformer = self.get_transformer(ProcrustesStatisticsFmt,
+                                           pd.DataFrame)
+        obs = transformer(input_fmt)
+
+        pdt.assert_frame_equal(exp, obs)
+
+    def test_procrustes_m2_stats_fmt_to_md(self):
+        filepath = self.get_data_path('m2stats-999-permus.tsv')
+        input_fmt = ProcrustesStatisticsFmt(filepath, mode='r')
+        df = pd.DataFrame({'true M^2 value': [0.0789623748362618],
+                           'p-value for true M^2 value': [0.001],
+                           'number of Monte Carlo permutations': [999]},
+                          index=pd.Index(['results'], name='id'))
+        exp = qiime2.Metadata(df)
+
+        transformer = self.get_transformer(ProcrustesStatisticsFmt,
+                                           qiime2.Metadata)
+        obs = transformer(input_fmt)
+
+        self.assertEqual(exp, obs)
+
 
 if __name__ == "__main__":
     unittest.main()
