@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2020, QIIME 2 development team.
+# Copyright (c) 2016-2021, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -336,8 +336,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -387,8 +389,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -436,8 +440,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -486,8 +492,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -537,8 +545,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -588,8 +598,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -638,8 +650,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
@@ -688,8 +702,10 @@ class TestFastqManifestTransformers(TestPluginBase):
             for o, e in zip(obs_fh, exp_fh):
                 self.assertEqual(o, e)
 
-        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)))
-        exp_metadata = yaml.load("{'phred-offset': 33}")
+        obs_metadata = yaml.load(open('%s/metadata.yml' % str(obs)),
+                                 Loader=yaml.SafeLoader)
+        exp_metadata = yaml.load("{'phred-offset': 33}",
+                                 Loader=yaml.SafeLoader)
         self.assertEqual(obs_metadata, exp_metadata)
 
         obs_manifest = open('%s/MANIFEST' % (str(obs))).read()
